@@ -71,6 +71,28 @@ export const TeamLBACEditorUnconnected = ({
   const [teamsWithoutLBAC, setTeamsWithoutLBAC] = useState<Set<string>>(new Set<string>());
   const [lbacTeamsWithoutTeamPermissions, setLBACTeamsWithoutTeamPermission] = useState<Set<string>>(new Set<string>());
   const teamLBACRules = useMemo(() => teamLBACConfig?.rules || [], [teamLBACConfig?.rules]);
+
+  // Calculate the size of LBAC rules and check if it exceeds 64KB
+  const lbacRulesSizeWarning = useMemo(() => {
+    if (!teamLBACRules.length) {
+      return null;
+    }
+
+    // Convert rules to JSON string to calculate size
+    const rulesJSON = JSON.stringify(teamLBACRules);
+    const sizeInBytes = new Blob([rulesJSON]).size; // More accurate than rulesJSON.length
+    const sizeInKB = sizeInBytes / 1024;
+
+    if (sizeInKB > 64) {
+      return {
+        sizeInKB,
+        message:
+          'Your LBAC rules are too large. This may result in slower queries and the inability to query the datasource if a user has too many rules applied to them. Consider splitting into separate data sources.',
+      };
+    }
+    return null;
+  }, [teamLBACRules]);
+
   const styles = useStyles2(getStyles);
   const [recommendationIsOpen, setRecommendationIsOpen] = useState(false);
 
@@ -200,6 +222,23 @@ export const TeamLBACEditorUnconnected = ({
   return (
     <Box paddingBottom={2}>
       {readOnly && <DataSourceReadOnlyMessage />}
+      {lbacRulesSizeWarning && (
+        <Box marginBottom={3}>
+          <Alert
+            title={t('team-lbac.team-lbaceditor-unconnected.lbac-size-warning-title', 'LBAC Rules Size Warning')}
+            severity="warning"
+          >
+            <p>{lbacRulesSizeWarning.message}</p>
+            <p>
+              <Text variant="bodySmall" color="secondary">
+                <Trans i18nKey="team-lbac.team-lbaceditor-unconnected.lbac-size-warning-details">
+                  Current size: {{ sizeInKB: Math.round(lbacRulesSizeWarning.sizeInKB) }}KB
+                </Trans>
+              </Text>
+            </p>
+          </Alert>
+        </Box>
+      )}
       <Stack direction="column" gap={3}>
         <ConfigSection
           title={t('team-lbac.team-lbaceditor-unconnected.title-data-access', 'Data access')}
